@@ -4,12 +4,11 @@
     Django-flash
     ~~~~~~~~~~~~
 
-    Rails-like flash context support for Django.
+    Rails-like flash scope support for Django.
 
     :copyright: 2008-2009, Destaquenet Technology Solutions.
     :license: LGPL v3.
 """
 
-__revision__ = '$Revision$'
-__version__ = '1.3.4'
-__released__ = '1.3.4'
+__version__ = '1.3.5'
+
